<?php

namespace Drupal\sidekick\Controller;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\OpenModalDialogCommand;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Language\LanguageInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Url;
use Drupal\Core\Config\ConfigManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns responses for Sidekick routes.
 */
class SidekickController extends ControllerBase {

  /**
   * The account manager.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $account;

  /**
   * The language manager.
   *
   * @var \Drupal\Core\Language\LanguageInterface
   */
  protected $language;

  /**
   * The config manager.
   *
   * @var \Drupal\Core\Config\ConfigManagerInterface
   */
  protected $configManager;

  /**
   * @param \Drupal\Core\Session\AccountInterface $account
   * @param \Drupal\Core\Language\LanguageManagerInterface $language
   * @param \Drupal\Core\Config\ConfigManagerInterface $configManager
   */
  public function __construct(AccountInterface $account, LanguageManagerInterface $language, ConfigManagerInterface $configManager) {
    $this->account = $account;
    $this->language = $language;
    $this->configManager = $configManager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('current_user'),
      $container->get('language_manager'),
      $container->get('config.manager')
    );
  }

  /**
   * Builds the response.
   */
  public function build() {
    $query_parameters = [
      'apikey' => $this->configManager->getConfigFactory()->get('sidekick.settings')->get('api_key'),
      'contentLanguage' => $this->language->getCurrentLanguage(LanguageInterface::TYPE_CONTENT)->getId(),
      'userId' => $this->account->getDisplayName(),
      'platform' => 'Drupal',
      'referral' => 'Acolono'
    ];
    $api_url = Url::fromUri('https://assistant.ai-sidekick.app/chat', ['query' => $query_parameters])->toString();

    $content = '<iframe src="' . $api_url . '" title="Sidekick" style="height:80vh;width:76vw" referrerpolicy ="origin"></iframe>';

    $response = new AjaxResponse();
    $response->addCommand(new OpenModalDialogCommand('Sidekick', $content, ['width' => '80vw']));

    return $response;
  }

}
