<?php

namespace Drupal\sidekick\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Sidekick settings.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'sidekick_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['sidekick.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['info'] = [
      '#type' => 'html_tag',
      '#tag' => 'h5',
      '#value' => $this->t('Please add  https://*.ai-sidekick.app/chat in your trustworthy iframe sources'),
    ];
    $form['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Key'),
      '#default_value' => $this->config('sidekick.settings')->get('api_key'),
      '#required' => TRUE
    ];
    $form['display_type'] = [
      '#type' => 'select',
      '#options' => [
        'inline' => $this->t('Inline'),
        'modal' => $this->t('Modal')
      ],
      '#title' => $this->t('Display type'),
      '#default_value' => $this->config('sidekick.settings')->get('display_type')
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $language_code = \Drupal::languageManager()->getCurrentLanguage()->getId();
    $api_key = $form_state->getValue('api_key');
    $sidekick_service = \Drupal::service('sidekick.service');
    $sidekickKeyStatus = $sidekick_service->checkKeyStatus($api_key, $language_code);

    if(is_object($sidekickKeyStatus)){
      $form_state->setErrorByName('api_key', '');

      $build_message = [
        '#type' => 'container',
        '#markup' => $sidekickKeyStatus->message,
        '#attributes' => ['class' => ['messages--error']],
      ];
      $message = \Drupal::service('renderer')->renderPlain($build_message);
      $this->messenger()->addError($message);
    }

    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('sidekick.settings')
      ->set('api_key', $form_state->getValue('api_key'))
      ->set('display_type', $form_state->getValue('display_type'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
