<?php

namespace Drupal\sidekick;

use GuzzleHttp\ClientInterface;
use GuzzleHttp\Exception\BadResponseException;
use GuzzleHttp\Exception\ClientException;
use GuzzleHttp\Exception\RequestException;
use GuzzleHttp\Exception\TransferException;

/**
 * Service for HTTP request.
 */
class SidekickService {
  /**
   * The HTTP client.
   *
   * @var \GuzzleHttp\ClientInterface
   */
  protected $http_client;

  /**
   * @var $key_status_api
   */
  protected $key_status_api;


  /**
   * Constructs a SidekickService object.
   *
   * @param \GuzzleHttp\ClientInterface $http_client
   *   The HTTP client.
   */
  public function __construct(ClientInterface $http_client) {
    $this->http_client = $http_client;
    $this->key_status_api = 'https://assistant.ai-sidekick.app/api/v1/apikey-status';
  }

  /**
   * @param $api_key
   * @param $language_code
   * @return array|mixed
   */
  public function checkKeyStatus($api_key, $language_code) {
    try {
      $response = $this->http_client->post($this->key_status_api, [
        'headers' => [
          'Content-Type' => 'application/json',
        ],
        'body' => json_encode([
          'token' => $api_key,
          'language' => $language_code
        ])
      ]);

      $statusCode = $response->getStatusCode();
      return $apiResponse = ['status' => $statusCode, 'message' => json_decode($response->getBody())];

    } catch (ClientException|RequestException|TransferException|BadResponseException $exception) {
      watchdog_exception('sidekick', $exception, NULL, [], 6);

      return json_decode((string)$exception->getResponse()->getBody());
    }
  }
}